@@ -137,14 +137,14 @@ __PACKAGE__->method_documentation({
      'data_source' => {
      	datatype => 'DataSource',
      	base_name => 'DataSource',
-     	description => 'Represents data source.  There are three types of data, they are CloudFileSystem, RequestFiles, HttpUri.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'file_info' => {
      	datatype => 'FileInfo',
      	base_name => 'FileInfo',
-     	description => 'Represents file information. Include of filename, filesize, and file content(base64String).',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
