@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# GetWorksheetColumnsRequest.name :   ,
-# GetWorksheetColumnsRequest.sheetName :   ,
-# GetWorksheetColumnsRequest.offset :   ,
+# GetWorksheetColumnsRequest.name : The file name.  ,
+# GetWorksheetColumnsRequest.sheetName : The worksheet name.  ,
+# GetWorksheetColumnsRequest.offset : The workdook folder.  ,
 # GetWorksheetColumnsRequest.count :   ,
-# GetWorksheetColumnsRequest.folder :   ,
-# GetWorksheetColumnsRequest.storageName :    
+# GetWorksheetColumnsRequest.folder : The folder where the file is situated.  ,
+# GetWorksheetColumnsRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_worksheet_columns' } = { 
-    	summary => '',
+    	summary => 'Retrieve descriptions of worksheet columns.',
         params => $params,
         returns => 'ColumnsResponse',
     };
@@ -140,21 +140,21 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'offset' => {
      	datatype => 'int',
      	base_name => 'offset',
-     	description => '',
+     	description => 'The workdook folder.',
      	format => '',
      	read_only => '',
      		},
@@ -168,14 +168,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
