@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -65,9 +64,7 @@ sub new {
 # PostAutofitWorkbookRowsRequest.endRow : End row.  ,
 # PostAutofitWorkbookRowsRequest.onlyAuto : Only auto.  ,
 # PostAutofitWorkbookRowsRequest.folder : The folder where the file is situated.  ,
-# PostAutofitWorkbookRowsRequest.storageName : The storage name where the file is situated.  ,
-# PostAutofitWorkbookRowsRequest.firstColumn : First column index.  ,
-# PostAutofitWorkbookRowsRequest.lastColumn : Last column index.   
+# PostAutofitWorkbookRowsRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -90,7 +87,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/{name}/autofitrows';
+    my $_resource_path = '/cells/{name}/autofitrows';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -126,19 +123,8 @@ sub run_http_request {
 
     if(defined $self->storage_name){
         $query_params->{'storageName'} = $client->to_query_value($self->storage_name);      
-    }
-
-    if(defined $self->first_column){
-        $query_params->{'firstColumn'} = $client->to_query_value($self->first_column);      
-    }
-
-    if(defined $self->last_column){
-        $query_params->{'lastColumn'} = $client->to_query_value($self->last_column);      
     } 
     my $_body_data;
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
@@ -189,20 +175,6 @@ __PACKAGE__->method_documentation({
      	base_name => 'storageName',
      	description => 'The storage name where the file is situated.',
      	format => '',
-     	read_only => '',
-     		},
-     'first_column' => {
-     	datatype => 'int',
-     	base_name => 'firstColumn',
-     	description => 'First column index.',
-     	format => '',
-     	read_only => '',
-     		},
-     'last_column' => {
-     	datatype => 'int',
-     	base_name => 'lastColumn',
-     	description => 'Last column index.',
-     	format => '',
      	read_only => '',
      		},    
 });
@@ -214,9 +186,7 @@ __PACKAGE__->attribute_map( {
     'end_row' => 'endRow',
     'only_auto' => 'onlyAuto',
     'folder' => 'folder',
-    'storage_name' => 'storageName',
-    'first_column' => 'firstColumn',
-    'last_column' => 'lastColumn' 
+    'storage_name' => 'storageName' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
