@@ -62,7 +62,8 @@ sub new {
 # PostConvertWorkbookToHtmlRequest.File : File to upload  ,
 # PostConvertWorkbookToHtmlRequest.password : The password needed to open an Excel file.  ,
 # PostConvertWorkbookToHtmlRequest.checkExcelRestriction : Whether check restriction of excel file when user modify cells related objects.  ,
-# PostConvertWorkbookToHtmlRequest.region : The regional settings for workbook.   
+# PostConvertWorkbookToHtmlRequest.region : The regional settings for workbook.  ,
+# PostConvertWorkbookToHtmlRequest.FontsLocation : Use Custom fonts.   
 
 {
     my $params = {
@@ -109,6 +110,10 @@ sub run_http_request {
 
     if(defined $self->region){
         $query_params->{'region'} = $client->to_query_value($self->region);      
+    }
+
+    if(defined $self->fonts_location){
+        $query_params->{'FontsLocation'} = $client->to_query_value($self->fonts_location);      
     } 
     my $_body_data;
  
@@ -156,6 +161,13 @@ __PACKAGE__->method_documentation({
      	base_name => 'region',
      	description => 'The regional settings for workbook.',
      	format => '',
+     	read_only => '',
+     		},
+     'fonts_location' => {
+     	datatype => 'string',
+     	base_name => 'FontsLocation',
+     	description => 'Use Custom fonts.',
+     	format => '',
      	read_only => '',
      		},    
 });
@@ -165,7 +177,8 @@ __PACKAGE__->attribute_map( {
     'file' => 'File',
     'password' => 'password',
     'check_excel_restriction' => 'checkExcelRestriction',
-    'region' => 'region' 
+    'region' => 'region',
+    'fonts_location' => 'FontsLocation' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
