@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -91,7 +90,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/{name}/worksheets/{sheetName}/pivottables/{pivotTableIndex}/PivotFields/{pivotFieldIndex}';
+    my $_resource_path = '/cells/{name}/worksheets/{sheetName}/pivottables/{pivotTableIndex}/PivotFields/{pivotFieldIndex}';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -144,14 +143,11 @@ sub run_http_request {
     } 
     my $_body_data;
 
-
     # body params
     if (defined $self->pivot_field) {
+        #$_body_data = $self->pivot_field;
          $_body_data = JSON->new->convert_blessed->encode( $self->pivot_field);
     }
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
