@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -85,7 +84,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/protect';
+    my $_resource_path = '/cells/protect';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -105,17 +104,18 @@ sub run_http_request {
     my $_body_data;
 
 
+    if (defined $self->file) {   
+        my $map_file = $self->file;
+        while ( my ($filename,$value) = each( %$map_file ) ) {
+                $form_params->{$filename} = [$value ,$filename,'application/octet-stream'];
+        }
+    } 
+
     # body params
     if (defined $self->protect_workbook_request) {
+        #$_body_data = $self->protect_workbook_request;
          $_body_data = JSON->new->convert_blessed->encode( $self->protect_workbook_request);
-         $form_params->{'protectWorkbookRequest'} = $_body_data ;
     }
-
-    if (defined $self->file) {   
-        $form_params->{basename($self->file)} = [$self->file ,basename($self->file),'application/octet-stream'];
-    }
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
