@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -71,7 +70,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_trim_content' } = { 
-    	summary => 'The PostTrimContent API is designed to process and trim content within a specified range in a spreadsheet. This API allows users to remove extra spaces, line breaks, or other unnecessary characters from the content of selected cells. It is particularly useful for cleaning up data entries and ensuring consistency in spreadsheet formatting',
+    	summary => '',
         params => $params,
         returns => 'FileInfo',
     };
@@ -83,7 +82,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/trimcontent';
+    my $_resource_path = '/cells/trimcontent';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -100,14 +99,11 @@ sub run_http_request {
  
     my $_body_data;
 
-
     # body params
     if (defined $self->trim_content_options) {
+        #$_body_data = $self->trim_content_options;
          $_body_data = JSON->new->convert_blessed->encode( $self->trim_content_options);
     }
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
